@@ -1,6 +1,7 @@
 import sense_core as sd
 from django.db.utils import IntegrityError
 from sense_push.common import *
+from django.db import connections
 
 
 class DjangoPushDataHandler(object):
@@ -105,6 +106,7 @@ class DjangoPushDataHandler(object):
         except IntegrityError as ex:
             sd.log_warn("IntegrityError for table={0} data2={1} msg={2}".format(table, data2, str(ex)))
         except Exception as ex:
+            self.close_model_connection()
             sd.log_exception(ex)
             sd.log_error("execption for table={0} data2={1} action={2}".format(table,  data2, action))
             raise ex
@@ -151,23 +153,32 @@ class DjangoPushDataHandler(object):
         return True
 
     def delete(self, database, table, data):
-        model_item = self._get_model(database, table)
-        if not model_item:
-            return
-        if not self.before_delete(database, table, data):
-            return
-        model = model_item['model']
-        data2 = dict(data)
-        res = self.build_primary_keys(data2, model_item['primary'])
-        if not res:
-            sd.log_error("build_primary_keys failed for data={0} primary={1}".format(data, model_item['primary']))
-            return
-        model.objects.filter(**res).delete()
-        sd.log_info("delete table={0} primary={1}".format(table, model_item['primary']))
-        self.callback_handle(PUSH_ACTION_DELETE, database, table, data)
+        try:
+            model_item = self._get_model(database, table)
+            if not model_item:
+                return
+            if not self.before_delete(database, table, data):
+                return
+            model = model_item['model']
+            data2 = dict(data)
+            res = self.build_primary_keys(data2, model_item['primary'])
+            if not res:
+                sd.log_error("build_primary_keys failed for data={0} primary={1}".format(data, model_item['primary']))
+                return
+            model.objects.filter(**res).delete()
+            sd.log_info("delete table={0} primary={1}".format(table, model_item['primary']))
+            self.callback_handle(PUSH_ACTION_DELETE, database, table, data)
+        except Exception as ex:
+            self.close_model_connection()
+            sd.log_exception(ex)
+            sd.log_error("delete error table={} data={}".format(table,data))
 
     def callback_handle(self, action, database, table, data):
         pass
 
     def handle_custom(self, database, table, data, action):
         self.callback_handle(action, database, table, data)
+
+    @sd.try_catch_exception
+    def close_model_connection(self):
+        connections.close_all()
